@@ -1,5 +1,5 @@
-jk.after.boot <- function(object, ncomp = object$ncomp, 
-                          type = c("coefficients", "loadings", "weights"),  
+jk.after.boot <- function(object, ncomp = object$ncomp,
+                          type = c("coefficients", "loadings", "weights"),
                           parm = NULL) {
   if ((object$val.method == "none" | object$val.method == "loo")) {
     stop("No bootstrapping was done for this model")
@@ -33,9 +33,9 @@ jab <- llply(1:Obj, function(this.obs) {
   coefficients.boot.out.cis <- mean(coefficients.boot.out, na.rm = T)
   coefficients.boot.in.cis <- mean(coefficients.boot.in.dat, na.rm = T)
   inf <- coefficients.boot.out.cis
-  Empirical.Quantiles.in <- quantile(coefficients.boot.in.dat, 
+  Empirical.Quantiles.in <- quantile(coefficients.boot.in.dat,
                                      prob = c(0.05, 0.1, 0.16, 0.5, 0.84, 0.9, 0.95), na.rm = T)
-  Empirical.Quantiles.out <- quantile(coefficients.boot.out, 
+  Empirical.Quantiles.out <- quantile(coefficients.boot.out,
                                       prob = c(0.05, 0.1, 0.16, 0.5, 0.84, 0.9, 0.95), na.rm = T)
   Out <- data.frame(Empirical.Quantiles.in, Empirical.Quantiles.out)
   Out$Percentile <- row.names(Out)
@@ -48,22 +48,21 @@ jab <- llply(1:Obj, function(this.obs) {
   infl.values <- (round(infl.bt / sqrt(sum(infl.bt^2 / (Obj - 1))), 2))
   Infl.values <- data.frame(infl.values, Obs = 1:Obj)
   df <- merge(df, Infl.values, by = "Obs")
-  # df.m <- melt(df, measure = c(2, 3))
-print(with(df, ggplot(df, aes(infl.values, Empirical.Quantiles.out)) + 
-        theme_bw() + 
-        theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) + 
-        geom_text(aes(label = as.factor(Obs))) + 
-        theme(legend.position = "none") + 
-        geom_line(aes(group = Percentile)) + 
-        geom_hline(data = df, aes(yintercept = Empirical.Quantiles.in), lty = 2) + 
-        xlab("Estimate of Relative Influence") + 
-        ylab("Empirical Quantiles") + 
-        ggtitle(paste("Jackknife-After-Boot (",  type,")\nfor Variable =", parm, "\nncomp =", ncomp)) +     
-        theme(plot.title = element_text(size = 20)) + 
-        theme(axis.title.x = element_text(size = 20)) +
-        theme(axis.title.y = element_text(size = 20, angle = 90)) + 
-        theme(axis.text.x = element_text(size = 15, angle = 90, vjust = 0.5, face = "bold")) + 
-        theme(axis.text.y = element_text(size = 15, angle = 0, face = "bold"))))
+print(with(df, ggplot(df, aes(infl.values, Empirical.Quantiles.out)) +
+        theme_bw() +
+        theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
+        geom_text(aes(label = as.factor(Obs)), size = 3) +
+        theme(legend.position = "none") +
+        geom_line(aes(group = Percentile)) +
+        geom_hline(data = df, aes(yintercept = Empirical.Quantiles.in), lty = 2) +
+        xlab("Estimate of Relative Influence") +
+        ylab("Empirical Quantiles") +
+        ggtitle(paste("Jackknife-After-Boot (",  type,")\nfor Variable =", parm, "\nncomp =", ncomp)) +
+        theme(plot.title = element_text(size = 20)) +
+        theme(axis.title.x = element_text(size = 15)) +
+        theme(axis.title.y = element_text(size = 15, angle = 90)) +
+        theme(axis.text.x = element_text(size = 10, angle = 90, vjust = 0.5, face = "bold")) +
+        theme(axis.text.y = element_text(size = 10, angle = 0, face = "bold"))))
 }
 
 
